@@ -644,8 +644,8 @@ class ChatMemberUpdated(TgObject):
     chat: Chat
     from_user: User
     date: int
-    old_chat_member: ChatMember
-    new_chat_member: ChatMember
+    old_chat_member: ChatMemberT
+    new_chat_member: ChatMemberT
     invite_link: ChatInviteLink = None
 
 
